@@ -33,7 +33,8 @@ from skops.hub_utils import (
 from skops.hub_utils._hf_hub import (
     _create_config,
     _get_column_names,
-    _get_example_input,
+    _get_example_input_from_tabular_data,
+    _get_example_input_from_text_data,
     _validate_folder,
 )
 from skops.hub_utils.tests.common import HF_HUB_TOKEN
@@ -230,7 +231,7 @@ def test_create_config(data, task, expected_config):
 
 
 def test_create_config_invalid_text_data(temp_path):
-    with pytest.raises(ValueError, match="The data needs to be a list of strings."):
+    with pytest.raises(ValueError, match="The data needs to be a sequence of strings."):
         _create_config(
             model_path="model.pkl",
             requirements=['scikit-learn="1.1.1"', "numpy"],
@@ -398,10 +399,15 @@ def test_push_download(
         private=True,
     )
 
-    with pytest.raises(
-        RepositoryNotFoundError,
-        match="If the repo is private, make sure you are authenticated.",
-    ):
+    # TODO: remove 1st message when huggingface_hub < v0.12 is dropped
+    # message changes in huggingface_hub v0.12, test both
+    match = (
+        "If the repo is private, make sure you are authenticated"
+        "|"
+        "If you are trying to access a private or gated repo, "
+        "make sure you are authenticated"
+    )
+    with pytest.raises(RepositoryNotFoundError, match=match):
         download(repo_id=repo_id, dst="/tmp/test")
 
     with pytest.raises(OSError, match="None-empty dst path already exists!"):
@@ -521,30 +527,68 @@ def test_update_env(repo_path, config_json):
     assert get_requirements(repo_path) == ['scikit-learn="1.1.2"']
 
 
-def test_get_example_input():
-    """Test the _get_example_input function."""
+def test_get_example_input_from_tabular_data():
     with pytest.raises(
-        ValueError, match="The data is not a pandas.DataFrame or a numpy.ndarray."
+        ValueError,
+        match=(
+            "The data is not a pandas.DataFrame, a 2D numpy.ndarray or a "
+            "list/tuple that can be converted to a 2D numpy.ndarray."
+        ),
     ):
-        _get_example_input(["a", "b", "c"])
+        _get_example_input_from_tabular_data("random")
+    with pytest.raises(ValueError):
+        _get_example_input_from_tabular_data(["a", "b", "c"])
 
-    examples = _get_example_input(np.ones((5, 10)))
-    # the result if a dictionary of column name: list of values
+    examples = _get_example_input_from_tabular_data(np.ones((5, 10)))
+    # the result is a dictionary of column name: list of values
     assert len(examples) == 10
     assert len(examples["x0"]) == 3
 
-    examples = _get_example_input(
+    examples = _get_example_input_from_tabular_data(np.ones((5, 10)).tolist())
+    # the result is a dictionary of column name: list of values
+    assert len(examples) == 10
+    assert len(examples["x0"]) == 3
+
+    examples = _get_example_input_from_tabular_data(
         pd.DataFrame(np.ones((5, 10)), columns=[f"column{x}" for x in range(10)])
     )
-    # the result if a dictionary of column name: list of values
+    # the result is a dictionary of column name: list of values
     assert len(examples) == 10
     assert len(examples["column0"]) == 3
 
 
+@pytest.mark.parametrize(
+    "data, expected_length",
+    [
+        (["a", "b", "c", "d"], 3),
+        (np.array(["a", "b", "c", "d"]), 3),
+        (set(["a", "b", "c", "d"]), 3),
+        (tuple(["a", "b", "c", "d"]), 3),
+        (["a"], 1),
+        ([], 0),
+    ],
+)
+def test_get_example_input_from_text_data(data, expected_length):
+    example_input = _get_example_input_from_text_data(data)
+    assert len(example_input["data"]) == expected_length
+
+
+@pytest.mark.parametrize("data", ["random", [1, 2, 3], 420])
+def test_get_example_input_from_text_data_invalid_text_data(data):
+    with pytest.raises(ValueError, match="The data needs to be a sequence of strings."):
+        _get_example_input_from_text_data(data)
+
+
 def test_get_column_names():
     with pytest.raises(
-        ValueError, match="The data is not a pandas.DataFrame or a numpy.ndarray."
+        ValueError,
+        match=(
+            "The data is not a pandas.DataFrame, a 2D numpy.ndarray or a "
+            "list/tuple that can be converted to a 2D numpy.ndarray."
+        ),
     ):
+        _get_column_names("random")
+    with pytest.raises(ValueError):
         _get_column_names(["a", "b", "c"])
 
     X_array = np.ones((5, 10), dtype=np.float32)
@@ -556,11 +600,11 @@ def test_get_column_names():
     assert _get_column_names(X_df) == expected_columns
 
 
-def test_get_example_input_pandas_not_installed(pandas_not_installed):
+def test_get_example_input_from_tabular_data_pandas_not_installed(pandas_not_installed):
     # use pandas_not_installed fixture from conftest.py to pretend that pandas
     # is not installed and check that the function does not raise when pandas
     # import fails
-    _get_example_input(np.ones((5, 10)))
+    _get_example_input_from_tabular_data(np.ones((5, 10)))
 
 
 def test_get_column_names_pandas_not_installed(pandas_not_installed):
@@ -658,3 +702,51 @@ class TestAddFiles:
         )
         with pytest.raises(FileExistsError, match=msg):
             add_files(some_file_0, dst=init_path)
+
+
+class TestUseIntelex:
+    # Tests related to the usage of scikit-learn intelex, see #251
+    def make_config(self, model, requirements, **kwargs):
+        dir_path = tempfile.mkdtemp()
+        shutil.rmtree(dir_path)
+
+        init(
+            model=model,
+            dst=dir_path,
+            task="tabular-classification",
+            data=iris.data,
+            requirements=requirements,
+            **kwargs,
+        )
+        config = get_config(dir_path)
+        return config
+
+    def test_no_intelex(self, classifier):
+        # by default, intelex is not being used
+        config = self.make_config(model=classifier, requirements=["foobar"])
+        environement = config["sklearn"]["environment"]
+
+        assert config["sklearn"]["use_intelex"] is False
+        assert not any(r.startswith("scikit-learn-intelex") for r in environement)
+
+    def test_use_intelex_but_not_explicitly_in_requirements(self, classifier):
+        # when using intelex, if it's not explicitly in the environment, add it
+        # automatically
+        config = self.make_config(
+            model=classifier, requirements=["foobar"], use_intelex=True
+        )
+        environement = config["sklearn"]["environment"]
+
+        assert config["sklearn"]["use_intelex"] is True
+        assert any(r == "scikit-learn-intelex" for r in environement)
+
+    def test_use_intelex_explicitly_in_requirements(self, classifier):
+        # when users specify intelex explicitly, it's not added automatically to
+        # the requirements
+        reqs = ["foobar", "scikit-learn-intelex==2023.0.0"]
+        config = self.make_config(model=classifier, requirements=reqs, use_intelex=True)
+        environement = config["sklearn"]["environment"]
+
+        assert config["sklearn"]["use_intelex"] is True
+        assert not any(r == "scikit-learn-intelex" for r in environement)
+        assert any(r == "scikit-learn-intelex==2023.0.0" for r in environement)
