@@ -1,5 +1,10 @@
+from __future__ import annotations
+
+import io
+import json
 import sys
 import warnings
+from zipfile import ZipFile
 
 import numpy as np
 from scipy import sparse
@@ -173,3 +178,88 @@ def assert_method_outputs_equal(estimator, loaded, X):
             X_out1 = getattr(estimator, method)(X)
             X_out2 = getattr(loaded, method)(X)
             assert_allclose_dense_sparse(X_out1, X_out2, err_msg=err_msg, atol=ATOL)
+
+
+def downgrade_state(*, data: bytes, keys: list[str], old_state: dict, protocol: int):
+    """Function to downgrade the persisted state of a skops object.
+
+    This function is important for testing upgrades to the skops persistence
+    protocol. When an upgrade is made, we add a test to ensure that the old
+    state can still be loaded successfully. For this, we need to generate a
+    state that looks like it came from the previous protocol. This function
+    helps doing that.
+
+    The caller should pass the new state, the path to the sub-state that needs
+    to be downgraded, the actual old state to be downgraded to, and the protocol
+    of that old version. Then this function will replace the new state with the
+    old state and insert the old protocol number. It also adds an ``__id__``
+    field, which is expected for memoization.
+
+    Here is an example of how to use it:
+
+    .. code:: python
+
+        estimator = ...
+        # get the state of the object using current protocol
+        dumped = sio.dumps(estimator)
+        # let's assume that estimator.foo.bar was changed
+        keys = ["foo", "bar"]
+        old_state = old_get_state_function(bar)
+        downgraded = downgrad_state(
+            data=dumped,
+            keys=keys,
+            old_state=old_state
+            protocol=current_protocol - 1,
+        )
+        # check that this does not raise an error:
+        sio.loads(downgrade, trusted=...)
+
+    Parameters
+    ----------
+    data : bytes
+        The old state, as generated by ``skops.io.dumps``.
+
+    keys : list of str, or None
+        The keys that lead to the old state. E.g. if we want to replace
+        ``state["foo"]["bar"]``, then keys should be ``["foo", "bar"]``. If
+        ``keys=None``, the whole schema is instead replaced by the old state
+        being passed.
+
+    old_state : dict
+        The old state, as would be produced by the old ``get_state`` function.
+
+    protocol : int
+        The protocol number corresponding to the old state.
+
+    Returns
+    -------
+    bytes
+        The old state, as would have been dumped by ``skops.io.dumps``.
+
+    """
+    # load from bytes
+    with ZipFile(io.BytesIO(data), "r") as zip_file:
+        schema = json.loads(zip_file.read("schema.json"))
+
+    # replace state in schema using old state
+    if keys is None:
+        # replace all fields
+        schema = old_state
+        schema["__id__"] = id(schema)
+    else:
+        # replace specific field
+        state = schema
+        for key in keys[:-1]:
+            state = state[key]
+        state[keys[-1]] = old_state
+
+        # there has to be an __id__ field for memoization
+        state[keys[-1]]["__id__"] = id(schema)
+
+    schema["protocol"] = protocol
+
+    # dump into bytes
+    buffer = io.BytesIO()
+    with ZipFile(buffer, "w") as zip_file:
+        zip_file.writestr("schema.json", json.dumps(schema, indent=2))
+    return buffer.getbuffer().tobytes()
